@@ -12,12 +12,15 @@ globalVariables(unique(c(
   "_id",
   # create_terminal_node_GL : <anonymous>:
   "_id",
+  # forest:
+  "id",
   # mse : mu1fun:
   "event",
   "event_count_pred",
   "t.stop",
   # mse_2:
   "event",
+  "id",
   "event_count_pred",
   "t.stop",
   # predict_node_terminal:
